@@ -13,7 +13,11 @@ use crate::{
         self, apply_data_target_path, check_target_not_found_err, copy_dir_recursive, path_exists,
         path_to_href, target_path,
     },
-    config::{CargoMetadata, CrossOrigin, Features, RtcBuild},
+    config::{
+        rt::{Features, RtcBuild},
+        types::CrossOrigin,
+        CargoMetadata,
+    },
     pipelines::rust::sri::{SriBuilder, SriOptions, SriType},
     processing::{integrity::IntegrityType, minify::minify_js},
     tools::{self, Application},
@@ -22,17 +26,15 @@ use anyhow::{anyhow, bail, ensure, Context, Result};
 use cargo_metadata::Artifact;
 use minify_js::TopLevelMode;
 use seahash::SeaHasher;
-use std::collections::HashSet;
-use std::hash::Hasher;
-use std::path::{Path, PathBuf};
-use std::process::Stdio;
-use std::str::FromStr;
-use std::sync::Arc;
-use tokio::fs;
-use tokio::io::AsyncWriteExt;
-use tokio::process::Command;
-use tokio::sync::mpsc;
-use tokio::task::JoinHandle;
+use std::{
+    collections::HashSet,
+    hash::Hasher,
+    path::{Path, PathBuf},
+    process::Stdio,
+    str::FromStr,
+    sync::Arc,
+};
+use tokio::{fs, io::AsyncWriteExt, process::Command, sync::mpsc, task::JoinHandle};
 use tracing::log;
 use wasm_bindgen::{find_wasm_bindgen_version, WasmBindgenTarget};
 use wasm_opt::WasmOptLevel;
@@ -43,6 +45,10 @@ pub struct RustApp {
     id: Option<usize>,
     /// Runtime config.
     cfg: Arc<RtcBuild>,
+    /// Skip building
+    skip_build: bool,
+    /// Cargo profile to use
+    cargo_profile: Option<String>,
     /// The configuration of the features passed to cargo.
     cargo_features: Features,
     /// Is this module main or a worker?
@@ -182,10 +188,6 @@ impl RustApp {
         let id = Some(id);
         let name = bin.clone().unwrap_or_else(|| manifest.package.name.clone());
 
-        let data_features = attrs.get("data-cargo-features").map(|val| val.to_string());
-        let data_all_features = attrs.contains_key("data-cargo-all-features");
-        let data_no_default_features = attrs.contains_key("data-cargo-no-default-features");
-
         let loader_shim = attrs.contains_key("data-loader-shim");
         if loader_shim {
             ensure!(
@@ -194,6 +196,30 @@ impl RustApp {
             );
         }
 
+        // cargo profile
+
+        let data_cargo_profile = match cfg.release {
+            true => attrs.get("data-cargo-profile-release"),
+            false => attrs.get("data-cargo-profile-dev"),
+        }
+        .or_else(|| attrs.get("data-cargo-profile"));
+
+        let cargo_profile = match data_cargo_profile {
+            Some(cargo_profile) => {
+                if let Some(config_cargo_profile) = &cfg.cargo_profile {
+                    log::warn!("Cargo profile from configuration ({config_cargo_profile}) will be overridden with HTML file's more specific setting ({cargo_profile})");
+                }
+                Some(cargo_profile.clone())
+            }
+            None => cfg.cargo_profile.as_ref().cloned(),
+        };
+
+        // cargo features
+
+        let data_features = attrs.get("data-cargo-features").map(|val| val.to_string());
+        let data_all_features = attrs.contains_key("data-cargo-all-features");
+        let data_no_default_features = attrs.contains_key("data-cargo-no-default-features");
+
         // Highlander-rule: There can be only one (prohibits contradicting arguments):
         ensure!(
             !(data_all_features && (data_no_default_features || data_features.is_some())),
@@ -213,6 +239,10 @@ impl RustApp {
             cfg.cargo_features.clone()
         };
 
+        // skip
+
+        let skip_build = attrs.contains_key("data-trunk-skip");
+
         // bindings
 
         let import_bindings = !attrs.contains_key("data-wasm-no-import");
@@ -239,6 +269,8 @@ impl RustApp {
         Ok(Self {
             id,
             cfg,
+            skip_build,
+            cargo_profile,
             cargo_features,
             manifest,
             ignore_chan,
@@ -285,7 +317,9 @@ impl RustApp {
 
         Ok(Some(Self {
             id: None,
+            skip_build: false,
             cargo_features: cfg.cargo_features.clone(),
+            cargo_profile: None,
             cfg,
             manifest,
             ignore_chan,
@@ -318,6 +352,10 @@ impl RustApp {
 
     #[tracing::instrument(level = "trace", skip(self))]
     async fn build(mut self) -> Result<TrunkAssetPipelineOutput> {
+        if self.skip_build {
+            return Ok(TrunkAssetPipelineOutput::None);
+        }
+
         // run the cargo build
         let wasm = self.cargo_build().await.context("running cargo build")?;
 
@@ -353,7 +391,10 @@ impl RustApp {
             "--manifest-path",
             &self.manifest.manifest_path,
         ];
-        if self.cfg.release {
+        if let Some(profile) = &self.cargo_profile {
+            args.push("--profile");
+            args.push(profile);
+        } else if self.cfg.release {
             args.push("--release");
         }
         if self.cfg.offline {
@@ -387,7 +428,7 @@ impl RustApp {
             }
         }
 
-        let build_res = common::run_command("cargo", Path::new("cargo"), &args)
+        let build_res = common::run_command("cargo", "cargo", &args, &self.cfg.working_directory)
             .await
             .context("error during cargo build execution");
 
@@ -411,6 +452,7 @@ impl RustApp {
         tracing::debug!("fetching cargo artifacts");
         args.push("--message-format=json");
         let artifacts_out = Command::new("cargo")
+            .current_dir(&self.cfg.core.working_directory)
             .args(args.as_slice())
             .stdout(Stdio::piped())
             .stderr(Stdio::piped())
@@ -475,10 +517,7 @@ impl RustApp {
             Application::WasmBindgen,
             version.as_deref(),
             self.cfg.offline,
-            &tools::HttpClientOptions {
-                root_certificate: self.cfg.root_certificate.clone(),
-                accept_invalid_certificates: self.cfg.accept_invalid_certs.unwrap_or(false),
-            },
+            &self.cfg.client_options(),
         )
         .await?;
 
@@ -524,9 +563,14 @@ impl RustApp {
 
         // Invoke wasm-bindgen.
         tracing::debug!("calling wasm-bindgen for {}", self.name);
-        common::run_command(wasm_bindgen_name, &wasm_bindgen, &args)
-            .await
-            .map_err(|err| check_target_not_found_err(err, wasm_bindgen_name))?;
+        common::run_command(
+            wasm_bindgen_name,
+            &wasm_bindgen,
+            &args,
+            &self.cfg.working_directory,
+        )
+        .await
+        .map_err(|err| check_target_not_found_err(err, wasm_bindgen_name))?;
 
         // Copy the generated WASM & JS loader to the dist dir.
         tracing::debug!("copying generated wasm-bindgen artifacts");
@@ -825,10 +869,7 @@ impl RustApp {
             Application::WasmOpt,
             version,
             self.cfg.offline,
-            &tools::HttpClientOptions {
-                root_certificate: self.cfg.root_certificate.clone(),
-                accept_invalid_certificates: self.cfg.accept_invalid_certs.unwrap_or(false),
-            },
+            &self.cfg.client_options(),
         )
         .await?;
 
@@ -863,7 +904,7 @@ impl RustApp {
 
         // Invoke wasm-opt.
         tracing::debug!("calling wasm-opt");
-        common::run_command(wasm_opt_name, &wasm_opt, &args)
+        common::run_command(wasm_opt_name, &wasm_opt, &args, &self.cfg.working_directory)
             .await
             .map_err(|err| check_target_not_found_err(err, wasm_opt_name))?;
 
