@@ -33,10 +33,12 @@ pub struct HttpClientOptions {
     /// Use this specific root certificate to validate the certificate chain. Optional.
     ///
     /// Useful when behind a corporate proxy that uses a self-signed root certificate.
+    #[cfg(any(feature = "native-tls", feature = "rustls"))]
     pub root_certificate: Option<PathBuf>,
     /// Allows Trunk to accept certificates that can't be verified when fetching dependencies. Defaults to false.
     ///
     /// **WARNING**: This is inherently unsafe and can open you up to Man-in-the-middle attacks. But sometimes it is required when working behind corporate proxies.
+    #[cfg(any(feature = "native-tls", feature = "rustls"))]
     pub accept_invalid_certificates: bool,
 }
 
@@ -271,7 +273,7 @@ pub async fn get(
                 )
             } else {
                 // a mismatch, so we need to download
-                tracing::info!("tool version mismatch (required: {required_version}, system: {detected_version})");
+                tracing::debug!("tool version mismatch (required: {required_version}, system: {detected_version})");
             }
         } else {
             // we don't require any specific version
@@ -350,6 +352,7 @@ async fn download(
 ) -> Result<PathBuf> {
     tracing::info!(version = version, "downloading {}", app.name());
 
+    #[cfg(any(feature = "native-tls", feature = "rustls"))]
     if client_options.accept_invalid_certificates {
         tracing::warn!(
             "Accept Invalid Certificates is set to true. This can open you up to MITM attacks."
@@ -458,7 +461,9 @@ pub async fn cache_dir() -> Result<PathBuf> {
     Ok(path)
 }
 
-async fn get_http_client(client_options: &HttpClientOptions) -> Result<reqwest::Client> {
+async fn get_http_client(
+    #[allow(unused_variables)] client_options: &HttpClientOptions,
+) -> Result<reqwest::Client> {
     let builder = reqwest::ClientBuilder::new();
 
     #[cfg(any(feature = "native-tls", feature = "rustls"))]
@@ -542,12 +547,7 @@ mod archive {
                     }
                 }
                 Self::None(in_file) => {
-                    let create_dir_result = std::fs::create_dir(target_directory);
-                    if let Err(e) = &create_dir_result {
-                        if e.kind() != std::io::ErrorKind::AlreadyExists {
-                            create_dir_result.context("failed to open file for")?;
-                        }
-                    }
+                    std::fs::create_dir_all(target_directory).context("failed to open file for")?;
 
                     let mut out_file_path = target_directory.to_path_buf();
                     out_file_path.push(file);
